@@ -1,26 +1,3 @@
-#' Helper function to find raster extension
-#' @param format (character) any of the format types allowed for raster objects.
-#' See \code{\link[raster]{writeFormats}} (e.g., "GTiff").
-#' @return Raster extension according to format type.
-#' @export
-#' @examples
-#' rformat <- rformat_type("GTiff")
-
-rformat_type <- function(format) {
-  if (missing(format)) {stop("Argument 'format needs to be defined.")}
-  if (format == "raster") {format1 <- ".grd"}
-  if (format == "GTiff") {format1 <- ".tif"}
-  if (format == "EHdr") {format1 <- ".bil"}
-  if (format == "ascii") {format1 <- ".asc"}
-  if (format == "SAGA") {format1 <- ".sdat"}
-  if (format == "IDRISI") {format1 <- ".rst"}
-  if (format == "CDF") {format1 <- ".nc"}
-  if (format == "ENVI") {format1 <- ".envi"}
-  if (format == "HFA") {format1 <- ".img"}
-  return(format1)
-}
-
-
 #' Helper function to create PDF files with histograms
 #' @param env_data list of environmental values in M for all species.
 #' @param occ_data list of environmental values in occurrences for all species.
@@ -42,7 +19,7 @@ rformat_type <- function(format) {
 #' @export
 #' @usage
 #' pdf_histograms(env_data, occ_data, y_values, sp_names, variable_name,
-#'   CL_lines, limits, col, output_directory)
+#'                CL_lines, limits, col, output_directory)
 #' @examples
 #' # example data
 #' e_data <- list(rnorm(1000, 15, 7), rnorm(800, 20, 6), rnorm(1000, 12, 3))
@@ -212,6 +189,7 @@ pdf_histograms <- function(env_data, occ_data, y_values, sp_names,
 }
 
 
+
 #' Helper function to prepare bin tables
 #' @param overall_range (numeric) minimum and maximum values of all species and
 #' Ms to be analyzed.
@@ -222,7 +200,6 @@ pdf_histograms <- function(env_data, occ_data, y_values, sp_names,
 #' species.
 #' @param bin_size (numeric) size of bins. Range of environmental values to
 #' be considered when creating each character in bin tables. See details.
-#' Default = 10.
 #' @details
 #' The argument \code{bin_size} helps to create characters that represent not
 #' only one value of an environmental variable, but a range of environmental
@@ -253,110 +230,57 @@ bin_env <- function(overall_range, M_range, sp_range, bin_size) {
 
   # sequences
   sequence_vals <- seq(overall_range[1], overall_range[2], bin_size)
+  nseq <- length(sequence_vals)
 
   # numeric ranges
-  if (bin_size > 1) {
-    ranges <- sapply(1:(length(sequence_vals) - 1), function(x){
-      if (x == 1) {
-        c(sequence_vals[x], sequence_vals[x + 1])
-      } else {
-        c(sequence_vals[x] + 1 , sequence_vals[x + 1])
-      }
-    })
+  ranges <- cbind(from = sequence_vals[-nseq], to = sequence_vals[-1])
+  n_bins <- nrow(ranges)
 
-    # character bins
-    bins <- sapply(1:(length(sequence_vals) - 1), function(x){
-      if (x == 1) {
-        paste(sequence_vals[x], sequence_vals[x + 1], sep = " to ")
-      } else {
-        paste(sequence_vals[x] + 1 , sequence_vals[x + 1], sep = " to ")
-      }
-    })
-  }
+  # character bins
+  bins <- paste(ranges[, 1], ranges[, 2], sep = " to ")
 
-  bin_tab <- lapply(1:dim(M_range)[1], function(i) {
-    M_test <- seq(round(M_range[i, 1]), round(M_range[i, 2]), 1)
-    sp_test <- seq(round(sp_range[i, 1]), round(sp_range[i, 2]), 1)
+  bin_tab <- lapply(1:nrow(M_range), function(x) {
+    seq_bins <- rep("?", nrow(ranges))
 
-    if (bin_size > 1) {
-      invar_M <- vector()
-      invar_sp <- vector()
+    wl <- which(ranges < M_range[x, 1], arr.ind = TRUE)
+    wh <- which(ranges > M_range[x, 2], arr.ind = TRUE)
 
-      for (j in 1:dim(ranges)[2]) {
-        if (sum(M_test %in% seq(ranges[1, j], ranges[2, j], 1)) > 0) {
-          invar_M[j] <- 1
-        } else {
-          invar_M[j] <- 0
-        }
+    if (nrow(wl) == 0) {wl <- matrix(1, ncol = 2)}
+    if (nrow(wh) == 0) {wh <- matrix(n_bins, ncol = 2)}
 
-        if (sum(sp_test %in% seq(ranges[1, j], ranges[2, j], 1)) > 0) {
-          invar_sp[j] <- 100
-        } else {
-          invar_sp[j] <- 0
-        }
-      }
+    wl1 <- which(ranges < sp_range[x, 1], arr.ind = TRUE)
+    wh1 <- which(ranges > sp_range[x, 2], arr.ind = TRUE)
 
-      invar_sum <- invar_M + invar_sp
-      n <- 1:length(invar_sum)
-      whereM <- range({
-        if (sum(invar_sum == 1) == 0) {c(0, 0)} else {n[invar_sum == 1]
-        }
-      })
-      wheresp <- range(n[invar_sum >= 100])
+    if (nrow(wl1) == 0) {wl1 <- matrix(1, ncol = 2)}
+    if (nrow(wh1) == 0) {wh1 <- matrix(n_bins, ncol = 2)}
 
-      places <- wheresp - whereM
+    fr <- max(wl[, 1])
+    to <- min(wh[, 1])
+    fr1 <- max(wl1[, 1])
+    to1 <- min(wh1[, 1])
 
-      if (places[1] > 0 & whereM[1] != 0) {invar_sum[1:(whereM[1] - 1)] <- 1}
+    condl <- M_range[x, 1] < sp_range[x, 1] & fr > 1 & fr == fr1
+    if (condl) {fr <- fr - 1}
 
-      if (places[2] <= 0) {invar_sum[(whereM[2] + 1):length(invar_sum)] <- 1}
-    } else {
-      invar_M <- vector()
-      invar_sp <- vector()
+    condh <- M_range[x, 2] > sp_range[x, 2] & to < n_bins & to == to1
+    if (condh) {to <- to + 1}
 
-      for (j in 1:length(sequence_vals)) {
-        if (sum(M_test %in% sequence_vals[j]) > 0) {
-          invar_M[j] <- 1
-        } else {
-          invar_M[j] <- 0
-        }
+    condl <- M_range[x, 1] < sp_range[x, 1]
+    if (condl) {seq_bins[1:fr] <- 0}
 
-        if (sum(sp_test %in% sequence_vals[j]) > 0) {
-          invar_sp[j] <- 100
-        } else {
-          invar_sp[j] <- 0
-        }
-      }
+    condh <- M_range[x, 2] > sp_range[x, 2]
+    if (condh) {seq_bins[to:n_bins] <- 0}
 
-      invar_sum <- invar_M + invar_sp
-      n <- 1:length(invar_sum)
-      whereM <- range({
-        if (sum(invar_sum == 1) == 0) {c(0, 0)} else {n[invar_sum == 1]}
-      })
-      wheresp <- range(n[invar_sum >= 100])
+    seq_bins[fr:to] <- "0"
+    seq_bins[fr1:to1] <- "1"
 
-      places <- wheresp - whereM
-
-      if (places[1] > 0 & whereM[1] != 0) {invar_sum[1:(whereM[1] - 1)] <- 1}
-      if (places[2] <= 0) {invar_sum[(whereM[2] + 1):length(invar_sum)] <- 1}
-    }
-
-    bin_tab <- vector()
-    for (j in 1:length(invar_sum)) {
-      if(invar_sum[j] == 0) bin_tab[j] <- "?"
-      if(invar_sum[j] == 1) bin_tab[j] <- "0"
-      if(invar_sum[j] >= 100) bin_tab[j] <- "1"
-    }
-
-    message("\t", i, " of ", dim(M_range)[1], " species finished")
-    return(bin_tab)
+    return(seq_bins)
   })
 
+  # putting all together
   bin_tab <- do.call(rbind, bin_tab)
-  if (bin_size > 1) {
-    colnames(bin_tab) <- bins
-  } else {
-    colnames(bin_tab) <- sequence_vals
-  }
+
+  colnames(bin_tab) <- bins
 
   return(bin_tab)
 }
@@ -520,28 +444,3 @@ score_tree <- function(tree_data, include_unknown = FALSE) {
   return(twd)
 }
 
-
-#' Helper function to split geographic points in 9 blocks of equal size
-#' @param data matrix with longitude and latitude columns, in that order.
-#' @export
-#' @examples
-#' # random data
-#' rdata <- cbind(x = rnorm(100, -80, 12), y = rnorm(100, -3, 15))
-#' blocks <- make_9blocks(rdata)
-
-make_9blocks <- function(data) {
-  if (missing(data)) {stop("Argument 'data' needs to be defined.")}
-  ndata <- nrow(data)
-  n1 <- ceiling(ndata / 3); n2 <- n1 * 2; n3 <- ndata - n2
-  xylor <- data[order(data[, 2]), ]
-  grp_a <- xylor[1:n1, ]
-  grp_b <- xylor[(n1 + 1):n2, ]
-  grp_c <- xylor[(n2 + 1):ndata, ]
-  sn1 <- ceiling(n1 / 3); sn3 <- n1 - (sn1 * 2)
-  sn7 <- ceiling(n3 / 3); sn9 <- n3 - (sn7 * 2)
-  all_gs <- c(rep(1, sn1), rep(2, sn1), rep(3, sn3), rep(4, sn1), rep(5, sn1),
-              rep(6, sn3), rep(7, sn7), rep(8, sn7), rep(9, sn9))
-  xyg <- cbind(rbind(grp_a[order(grp_a[, 1]), ], grp_b[order(grp_b[, 1]), ],
-                     grp_c[order(grp_c[, 1]), ]), all_gs)
-  return(xyg)
-}
